@@ -3,6 +3,7 @@ import os
 import random
 import string
 import time
+from datetime import datetime
 from pathlib import Path
 from typing import Dict, Optional
 
@@ -12,6 +13,15 @@ import psutil
 from hapless import config
 from hapless.utils import allow_missing
 
+"""
+paused
+running
+finished
+* finished(failed) non-zero rc
+* finished(success) zero rc
+💀
+"""
+
 
 class Hap(object):
     def __init__(
@@ -56,26 +66,30 @@ class Hap(object):
                 f.write(cmd)
 
     def _set_pid(self, pid: int):
-        if not psutil.pid_exists(pid):
-            raise ValueError(f"Cannot attach, pid {pid} doesn't exist")
-
         with open(self._pid_file, "w") as pid_file:
             pid_file.write(f"{pid}")
 
+        if not psutil.pid_exists(pid):
+            raise RuntimeError(f"Process with pid {pid} is gone")
+
     def _set_env(self):
         proc = self.proc
         if proc is None:
             raise RuntimeError("Cannot get environment for the non-running process")
 
+        environ = proc.environ()
         with open(self._env_file, "w") as env_file:
-            env_file.write(json.dumps(proc.environ()))
+            env_file.write(json.dumps(environ))
 
     def attach(self, pid: int):
         """
         Associate hap object with existing process by pid
         """
-        self._set_pid(pid)
-        self._set_env()
+        try:
+            self._set_pid(pid)
+            self._set_env()
+        except RuntimeError:
+            pass
 
     @staticmethod
     def get_random_name(length: int = 6):
@@ -130,6 +144,22 @@ class Hap(object):
 
         return humanize.naturaldelta(runtime)
 
+    @property
+    def start_time(self) -> Optional[str]:
+        if self._pid_file.exists():
+            return datetime.fromtimestamp(os.path.getmtime(self._pid_file)).strftime(
+                config.DATETIME_FORMAT
+            )
+        # log "Hap has not started yet"
+
+    @property
+    def end_time(self) -> Optional[str]:
+        if self._rc_file.exists():
+            return datetime.fromtimestamp(os.path.getmtime(self._rc_file)).strftime(
+                config.DATETIME_FORMAT
+            )
+        # log "Hap has not finished yet"
+
     @property
     def active(self) -> bool:
         return self.proc is not None
@@ -145,6 +175,7 @@ class Hap(object):
             return int(f.read())
 
     @property
+    @allow_missing
     def env(self) -> Dict[str, str]:
         proc = self.proc
         if proc is not None:
