@@ -10,6 +10,7 @@ try:
 except ModuleNotFoundError:
     # Fallback for Python 3.7
     from importlib_metadata import version
+
 from pathlib import Path
 from typing import Dict, List, Optional
 
@@ -23,14 +24,6 @@ from hapless import config
 from hapless.hap import Hap
 from hapless.utils import wait_created
 
-"""
-paused
-running
-finished
-* finished(failed) non-zero rc
-* finished(success) zero rc
-💀
-"""
 console = Console(highlight=False)
 
 
@@ -90,8 +83,20 @@ class Hapless(object):
         cmd_text = Text(f"{hap.cmd}", style=f"{config.COLOR_ACCENT} bold")
         status_table.add_row("Command:", cmd_text)
 
+        if verbose:
+            status_table.add_row("Stdout file:", f"{hap.stdout_path}")
+            status_table.add_row("Stderr file:", f"{hap.stderr_path}")
+
         status_table.add_row("Runtime:", f"{hap.runtime}")
 
+        start_time = hap.start_time
+        end_time = hap.end_time
+        if verbose and start_time:
+            status_table.add_row("Start time:", f"{start_time}")
+
+        if verbose and end_time:
+            status_table.add_row("End time:", f"{end_time}")
+
         status_panel = Panel(
             status_table,
             expand=verbose,
@@ -100,11 +105,12 @@ class Hapless(object):
         )
         console.print(status_panel)
 
-        if verbose:
+        environ = hap.env
+        if verbose and environ is not None:
             env_table = Table(show_header=False, show_footer=False, box=None)
             env_table.add_column("", justify="right")
             env_table.add_column("", justify="left", style=config.COLOR_ACCENT)
-            environ = hap.env
+
             for key, value in environ.items():
                 env_table.add_row(key, Text(value, overflow="fold"))
 
